@@ -148,8 +148,11 @@ void draw_window(Window win)
 				);
 	}
 
-	percentage = (int) ( ((float)free_mem) /
+	if ( state.fresh.total )
+		percentage = (int) ( ((float)free_mem) /
 			((float)state.fresh.total) * 100);
+	else
+		percentage = 0;
 	if (percentage >= 100) 
 		tmp[0] = percentage / 100;
 	else
@@ -302,9 +305,12 @@ void draw_window(Window win)
 				);
 	}
 
-	percentage = (int) (
+	if ( state.fresh.swap_total )
+		percentage = (int) (
 			((float)free_mem) /
 			((float)state.fresh.swap_total) * 100);
+	else
+		percentage = 0;
 	if (percentage >= 100) 
 		tmp[0] = percentage / 100;
 	else
